package org.libre.agosto.p2play

import android.opengl.Visibility
import android.os.AsyncTask
import android.support.v7.app.AppCompatActivity
import android.os.Bundle
import android.os.Looper
import android.support.v4.content.ContextCompat
import android.util.Log
import android.view.View
import com.squareup.picasso.Picasso
import kotlinx.android.synthetic.main.activity_reproductor.*
import org.libre.agosto.p2play.ajax.Actions
import org.libre.agosto.p2play.models.VideoModel

class ReproductorActivity : AppCompatActivity() {
    lateinit var video:VideoModel
    private val _actions: Actions = Actions()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_reproductor)
        ManagerSingleton.context = this

        videoView.settings.javaScriptEnabled = true
        videoView.settings.allowContentAccess = true
        videoView.settings.javaScriptCanOpenWindowsAutomatically = true
        videoView.settings.allowFileAccess = true
        videoView.settings.allowFileAccessFromFileURLs = true
        videoView.settings.allowUniversalAccessFromFileURLs = true
        videoView.settings.domStorageEnabled = true

        try {
            this.video =  this.intent.extras.getSerializable("video") as VideoModel
            tittleVideoTxt.text = this.video.name
            viewsTxt.text = this.video.views.toString() + ' ' + getString(R.string.view_text)
            userTxt.text = this.video.username
            descriptionVideoTxt.text = this.video.description

            if(this.video.userImageUrl!="")
                Picasso.get().load("https://"+ManagerSingleton.url+this.video.userImageUrl).into(userImg)
            videoView.loadUrl("https://"+ManagerSingleton.url+this.video.embedUrl)
            Log.d("url", videoView.url)
        }
        catch (err:Exception){
            err.printStackTrace()
            Log.d("Error", err?.message)
        }

        // subscribeBtn.setOnClickListener { ManagerSingleton.Toast(getString(R.string.comming)) }
        subscribeBtn.setOnClickListener { subscribe() }
        likeLayout.setOnClickListener { rate("like") }
        dislikeLayout.setOnClickListener { rate("dislike") }
    }

    fun subscribe(){
        val account = this.video.userUuid+"@"+this.video.userHost
        AsyncTask.execute {
            if (Looper.myLooper() == null)
                Looper.prepare()
            val res = this._actions.subscribe(ManagerSingleton.token.token, account)
            if (res == 1) {
                runOnUiThread {
                    ManagerSingleton.Toast(getString(R.string.subscribeMsg))
                    this.changeSubscribeBtn(true)
                }
            }
        }
    }

    fun unSubscribe(){
        val account = this.video.userUuid+"@"+this.video.userHost
        AsyncTask.execute {
            if (Looper.myLooper() == null)
                Looper.prepare()
            val res = this._actions.unSubscribe(ManagerSingleton.token.token, account)
            if (res == 1) {
                runOnUiThread {
                    ManagerSingleton.Toast(getString(R.string.unSubscribeMsg))
                    this.changeSubscribeBtn(false)
                }
            }
        }
    }

    fun rate(rate: String){
        AsyncTask.execute {
            if (Looper.myLooper() == null)
                Looper.prepare()
            val res = this._actions.rate(ManagerSingleton.token.token, this.video.id, rate)
            if (res == 1) {
                runOnUiThread {
                    ManagerSingleton.Toast(getString(R.string.rateMsg))
                    if(rate=="like"){
                        likeLayout.setBackgroundColor(ContextCompat.getColor(this, R.color.colorLike))
                        dislikeLayout.background = null
                    }
                    else if(rate=="dislike"){
                        dislikeLayout.setBackgroundColor(ContextCompat.getColor(this, R.color.colorDislike))
                        likeLayout.background = null
                    }
                }
            }
        }
    }

    fun getRate(){
        AsyncTask.execute {
            if (Looper.myLooper() == null)
                Looper.prepare()
            val rate = this._actions.getRate(ManagerSingleton.token.token, this.video.id)
            runOnUiThread {
                when (rate){
                    "like" -> {
                        likeLayout.setBackgroundColor(ContextCompat.getColor(this, R.color.colorLike))
                        dislikeLayout.background = null
                    }
                    "dislike" -> {
                        dislikeLayout.setBackgroundColor(ContextCompat.getColor(this, R.color.colorDislike))
                        likeLayout.background = null
                    }
                    else -> {
                        likeLayout.background = null
                        dislikeLayout.background = null
                    }
                }
            }
        }
    }

    fun getSubscription(){
        val account = this.video.userUuid+"@"+this.video.userHost
        AsyncTask.execute {
            if (Looper.myLooper() == null)
                Looper.prepare()
            val isSubscribed = this._actions.getSubscription(ManagerSingleton.token.token, account)
            runOnUiThread {
                this.changeSubscribeBtn(isSubscribed)
            }
        }
    }

    fun changeSubscribeBtn(subscribed: Boolean){
        if(subscribed){
            subscribeBtn.text = getText(R.string.unSubscribeBtn)
            subscribeBtn.setOnClickListener { this.unSubscribe() }
        }
        else{
            subscribeBtn.text = getText(R.string.subscribeBtn)
            subscribeBtn.setOnClickListener { this.subscribe() }
        }
    }

    override fun onResume() {
        super.onResume()
        if(ManagerSingleton.user.status == 1) {
            this.getRate()
            this.getSubscription()
            actionsLayout.visibility = View.VISIBLE
            subscribeBtn.visibility = View.VISIBLE
        }
    }
}
